pub struct NodeID {
pub namespace: String,
pub local_id: String,
}Fields
namespace: StringEach node is namespaced according to its Cluster.
local_id: StringAn ID should be locally unique inside a Cluster and is used to refer to a node inside its Cluster.
The ID also be used to refer to the node from outside its Cluster, if it is preceded by the Cluster’s namespace prefix.
Implementations
Sourceimpl NodeID
impl NodeID
pub fn from_two_part_string(string: &str) -> Result<NodeID, StructuralError>